# Changelog

## 0.3.0

- Added decomposition for multi-controlled quantum gates.

## 0.2.3

- Added the function `plugin` to the module `gates`.

## 0.2.2

- Refactored the `Quant` and gate functions implementations.

## 0.2.1

- Added the `Quant` type and gate functions.

## 0.2.0

- Added dump types "shots" and "probability".

## 0.1.1

- Fixed inverse gate application.

## 0.1.0

- Libket ported from C++ to Rust.
